@@ -2,7 +2,7 @@
 #
 # Red Hat Network registration tool
 # Adapted from wrapper.py
-# Copyright (c) 1999-2006 Red Hat, Inc.  Distributed under GPLv2.
+# Copyright (c) 1999--2012 Red Hat, Inc.  Distributed under GPLv2.
 #
 # Authors:
 #       Adrian Likins <alikins@redhat.com>
@@ -48,7 +48,7 @@ class ProfileCli(rhncli.RhnCli):
        
         if support is not None:
             print _("Updating virtualization profile...")
-            support.refresh()
+            support.refresh(True)
 
 
 if __name__ == "__main__":
