@@ -22,7 +22,13 @@ import os
 import sys
 import config
 
-import ethtool
+try:
+    import ethtool
+    ethtool_present = True
+except ImportError:
+    sys.stderr.write("Warning: information about network interfaces could not be retrieved on this platform.\n")
+    ethtool_present = False
+
 import gettext
 t = gettext.translation('rhn-client-tools', fallback=True)
 _ = t.ugettext
@@ -338,7 +344,7 @@ def read_cpuinfo():
 def read_memory():
     un = os.uname()
     kernel = un[2]
-    if kernel[:3] == "2.6":
+    if kernel[:3] >= "2.6":
         return read_memory_2_6()
     if kernel[:3] == "2.4":
         return read_memory_2_4()
@@ -524,6 +530,10 @@ def read_network_interfaces():
     intDict = {}
     intDict['class'] = "NETINTERFACES"
 
+    if not ethtool_present:
+        # ethtool is not available on non-linux platforms (as kfreebsd), skip it
+        return intDict
+
     interfaces = list(set(ethtool.get_devices() + ethtool.get_active_devices()))
     for interface in interfaces:
         try:
