@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # String constants for the RHN Register TUI/GUI.
-# Copyright (c) 2000--2011 Red Hat, Inc.
+# Copyright (c) 2000--2012 Red Hat, Inc.
 #
 # Author:
 #       James Slagle <jslagle@redhat.com>
@@ -17,11 +17,11 @@ COPYRIGHT_TEXT        = _(u"Copyright © 2006--2010 Red Hat, Inc. All rights res
 CONNECT_WINDOW        = _("Attempting to contact the Red Hat Network server.")
 CONNECT_WINDOW_TEXT   = _("We are attempting to contact the Red Hat "
                           "Network server at %s.")
-CONNECT_WINDOW_TEXT2  = _("A proxy was specified at %s.")                          
+CONNECT_WINDOW_TEXT2  = _("A proxy was specified at %s.")
 
 # Start Window
-START_REGISTER_WINDOW = _("Registering for software updates")
-START_REGISTER_TEXT   = _("This assistant will guide you through " 
+START_REGISTER_WINDOW = _("System Registration")
+START_REGISTER_TEXT   = _("This assistant will guide you through "
                           "connecting your system to "
                           "Red Hat Network (RHN) to receive software "
                           "updates, including "
@@ -34,7 +34,7 @@ START_REGISTER_TEXT   = _("This assistant will guide you through "
                           "or Proxy (optional)\n\n")
 
 # Why Register Window
-WHY_REGISTER          = _("Why Should I Connect to RHN? ...")                  
+WHY_REGISTER          = _("Why Should I Connect to RHN? ...")
 WHY_REGISTER_WINDOW   = _("Why Register")
 WHY_REGISTER_TEXT     = _("Connecting your system to Red Hat Network allows you to take full "
                           "advantage of the benefits of a paid subscription, including:")
@@ -50,14 +50,13 @@ WHY_REGISTER_SUPP_TXT = _("Access to the technical support experts at Red Hat or
                           "with any issues you might encounter with this system.")
 WHY_REGISTER_COMP_TXT = _("Stay in compliance with your subscription agreement "
                           "and manage subscriptions "
-                          "for systems connected to your account at "
-                          "http://rhn.redhat.com/.")
+                          "for systems connected to your account.")
 WHY_REGISTER_TIP      = _("Tip: Red Hat values your privacy: "
                           "http://www.redhat.com/legal/privacy_statement.html")
 BACK_REGISTER         = _("Take me back to the registration")
 
 # Confirm Quit Window
-CONFIRM_QUIT           = _("Software update setup unsuccessful")
+CONFIRM_QUIT           = _("Software Update Not Set Up")
 CONFIRM_QUIT_SURE       = _("Are you sure you don't want to connect your system to Red Hat Network? "
                            "You'll miss out on the benefits of a Red Hat Enterprise Linux subscription:\n")
 CONFIRM_QUIT_WILLNOT       = _("You will not be able to take advantage of these subscription privileges without connecting "
@@ -66,7 +65,7 @@ CONTINUE_REGISTERING   = _("Take me back to the setup process.")
 REGISTER_LATER2        = _("I'll register later.")
 
 # Info Window
-REGISTER_WINDOW   = _("Enter you account information")
+REGISTER_WINDOW   = _("Red Hat Account")
 LOGIN_PROMPT      = _("Please enter your login information for the %s Red "
                     "Hat Network Satellite:\n\n")
 HOSTED_LOGIN      = _("Red Hat Login:")
@@ -78,7 +77,7 @@ USER_REQUIRED     = _("Please enter a desired login.")
 PASSWORD_REQUIRED = _("Please enter and verify a password.")
 
 # OS Release Window
-SELECT_OSRELEASE             = _("Select operating system release")
+SELECT_OSRELEASE             = _("Operating System Release Version")
 OS_VERSION                   = _("Operating System version:")
 MINOR_RELEASE                = _(" Minor Release: ")
 LIMITED_UPDATES              = _("Limited Updates Only")
@@ -89,7 +88,7 @@ CONFIRM_OS_ALL               = _("Your system will be subscribed to the base"
                                  " updates.")
 
 # Hardware Window
-HARDWARE_WINDOW = _("Create your system profile - Hardware")
+HARDWARE_WINDOW = _("Create Profile - Hardware")
 HARDWARE_WINDOW_DESC1 = _("A Profile Name is a descriptive name that"
                           " you choose to identify this System Profile"
                           " on the Red Hat Network web pages. Optionally,"
@@ -101,7 +100,7 @@ HARDWARE_WINDOW_CHECKBOX = _("Include the following information about hardware"
                              " and network:")
 
 # Packages Window
-PACKAGES_WINDOW         = _("Create your system profile - Packages")
+PACKAGES_WINDOW         = _("Create Profile - Packages")
 PACKAGES_WINDOW_DESC1   = _("RPM information is important to determine what"
                           " updated software packages are relevant to this"
                           " system.")
@@ -112,20 +111,16 @@ PACKAGES_WINDOW_UNCHECK = _("You may deselect individual packages by"
 PACKAGES_WINDOW_PKGLIST = _("Building Package List")
 
 # Product Window
-HOSTED_LOGIN_PROMPT    = _("Please enter your login information for Red "
-                           "Hat Network (http://rhn.redhat.com/):\n\n")
-HOSTED_LOGIN_TIP       = _("Tip: Forgot your login or password? " 
-                            "Visit: https://rhn.redhat.com/rhn/sales/LoginInfo.do")
 EMAIL                  = _("*Email Address:")
 
-SYSTEM_ALREADY_SETUP = _("System already registered")
+SYSTEM_ALREADY_SETUP = _("System Already Registered")
 SYSTEM_ALREADY_REGISTERED = _("It appears this system has already been set up for software updates:")
 SYSTEM_ALREADY_REGISTERED_CONT = _("Are you sure you would like to continue?")
 
 RHSM_SYSTEM_ALREADY_REGISTERED = _("This system has already been registered with RHN"
 				" using RHN certficate-based technology.\n\n"
-				"The tool you are using is attempting to re-register"
-				" using RHN Classic technology. Red Hat recommends "
+				"The tool you are using is attempting to re-register "
+				"using RHN Satellite or RHN Proxy technology. Red Hat recommends "
 				"(except in a few cases) that customers only register with RHN once.\n\n"
 				"To learn more about RHN registration and technologies please consult this"
 				" Knowledge Base Article: https://access.redhat.com/kb/docs/DOC-45563")
@@ -142,7 +137,7 @@ SEND_WINDOW_DESC = _("We are finished collecting information for the System Prof
 SENDING_WINDOW = _("Sending Profile to Red Hat Network")
 
 # Finish Window
-FINISH_WINDOW           = _("Finish setting up software updates")
+FINISH_WINDOW           = _("Updates Configured")
 FINISH_WINDOW_TEXT_TUI  = _("You may now run 'yum update' from this system's "
                             "command line to get the latest "
                             "software updates from Red Hat Network. You will need to run this "
@@ -154,35 +149,21 @@ FINISH_WINDOW_TEXT_TUI  = _("You may now run 'yum update' from this system's "
                             "Hat Network web interface.)")
 
 # Review Window
-REVIEW_WINDOW           = _("Review system subscription details")
+REVIEW_WINDOW           = _("Review Subscription")
 REVIEW_WINDOW_PROMPT    = _("Please review the subscription details below:")
 SUB_NUM                 = _("The installation number %s was activated during "
                             "this system's initial connection to Red Hat Network.")
 SUB_NUM_RESULT          = _("Subscriptions have been activated for the following "
                             "Red Hat products/services:")
-CHANNELS_TITLE          = _("Software channel subscriptions:")
+CHANNELS_TITLE          = _("Software Channel Subscriptions:")
 OK_CHANNELS             = _("This system will receive updates from the "
-                            "following Red Hat Network software channels:")
-CHANNELS_SAT_WARNING    = _("Warning: If an installed product on this system "
-                            "is not listed above, you "
-                            "will not receive updates or support for that "
-                            "product. If you would like "
-                            "to receive updates for that product, please "
+                            "following software channels:")
+CHANNELS_SAT_WARNING    = _("Warning: Only installed product listed above will receive "
+                            "updates and support. If you would like "
+                            "to receive updates for additional products, please "
                             "login to your satellite web interface "
                             "and subscribe this system to the appropriate "
-                            "software channels to get updates for that "
-                            "product. See Kbase article 11313 "
-                            "for more details. "
-                            "(http://kbase.redhat.com/faq/docs/DOC-11313)")
-CHANNELS_HOSTED_WARNING = _("Warning: If an installed product on this system "
-                            "is not listed above, you "
-                            "will not receive updates or support for that "
-                            "product. If you would like "
-                            "to receive updates for that product, please "
-                            "visit http://rhn.redhat.com/ "
-                            "and subscribe this system to the appropriate "
-                            "software channels to get updates for that "
-                            "product. See Kbase article 11313 "
+                            "software channels. See Kbase article"
                             "for more details. "
                             "(http://kbase.redhat.com/faq/docs/DOC-11313)")
 YUM_PLUGIN_WARNING		= _("Warning: yum-rhn-plugin is not present, could not enable it.\n"
@@ -196,20 +177,15 @@ FAILED_CHANNELS         = _("You were unable to be subscribed to the following "
                             "subscriptions available in your account:")
 NO_BASE_CHANNEL            = _(
 "This system was unable to subscribe to any software channels. Your system "
-"will not receive any software updates to keep it secure and supported. There "
-"are a few things you can try to resolve this situation:\n(1) Log in to "
-"http://rhn.redhat.com/ and unentitle an inactive system at "
-"Your RHN > Subscription Management > System Entitlements.\n"
-"(2) Purchase an additional Red Hat Enterprise Linux subscription at "
-"http://www.redhat.com/store/.\n(3) Activate a new "
-"installation number at http://www.redhat.com/now/. Once you make the "
+"will not receive any software updates to keep it secure and supported. "
+"Contact your Satellite administrator about this problem. Once you make the "
 "appropriate active subscriptions available in your account, you may browse "
 "to this system's profile in the RHN web interface and subscribe this system "
 "to software channels via the software > software channels tab.")
-SLOTS_TITLE             = _("RHN service level:")
-OK_SLOTS                = _("Depending on what RHN modules are associated with a system, you'll "
-                            "enjoy different benefits of Red Hat Network. The following are the "
-                            "RHN modules associated with this system:")
+SLOTS_TITLE             = _("Service Level:")
+OK_SLOTS                = _("Depending on what RHN Satellite modules are associated with a system, you'll "
+                            "enjoy different benefits. The following are the "
+                            "RHN Satellite modules associated with this system:")
 SLOTS                   =  SLOTS_TITLE + "\n" + OK_SLOTS + "\n%s"
 FAILED_SLOTS            = _("This system was unable to be associated with the "
                             "following RHN module(s) because there were "
@@ -220,7 +196,7 @@ MANAGEMENT              = _("Management module: automatic updates, systems "
                             "grouping, systems permissions, system package profiling")
 PROVISIONING            = _("Provisioning module: bare-metal provisioning, existing state provisioning, "
                             "rollbacks, configuration management")
-MONITORING              = _("Monitoring module: pre-defined and custom system " 
+MONITORING              = _("Monitoring module: pre-defined and custom system "
                             "performance probes, system performance email "
                             "notifications, graphs of system performance")
 
@@ -241,25 +217,20 @@ VIRT_FAILED = _("<b>Warning:</b> Any guest systems you create on this system "
 
 NO_SYS_ENTITLEMENT         = _("This system was unable to be associated with "
 "any RHN service level modules. This system will not receive any software "
-"updates to keep it secure and supported. There "
-"are a few things you can try to resolve this situation:\n(1) Log in to "
-"http://rhn.redhat.com/ and unentitle an inactive system at "
-"Your RHN > Subscription Management > System Entitlements.\n"
-"(2) Purchase an additional Red Hat Enterprise Linux subscription at "
-"http://www.redhat.com/store/.\n(3) Activate a new "
-"installation number at http://www.redhat.com/now/. Once you make the "
+"updates to keep it secure and supported. Contace your Satellite administrator "
+"about this problem. Once you make the "
 "appropriate active subscriptions available in your account, you may browse "
 "to this system's profile in the RHN web interface, delete the profile, and "
 "re-connect this system to Red Hat Network.")
 ACTIVATION_KEY          = _("Universal default activation key detected\n"
-                            "A universal default activation key was detected in your RHN organization. "
-                            "What this means is that a set of properties (software channel subscriptions, " 
-                            "Red Hat Network service, package installations, system group memberships, etc.) "
-                            "for your system's connection to Red Hat Network "
+                            "A universal default activation key was detected in your account. "
+                            "This means that a set of properties (software channel subscriptions, "
+                            "package installations, system group memberships, etc.) "
+                            "for your system's connection to RHN Satellite or RHN Proxy"
                             "have been determined by the activation key rather than your "
-                            "installation number.  " 
+                            "installation number.  "
                             "You may also refer to the RHN Reference Guide, section 6.4.6 for more details "
-                            "about activation keys (http://rhn.redhat.com/rhn/help/reference/)\n"
+                            "about activation keys (http://access.redhat.com/knowledge/docs/Red_Hat_Network/)\n"
                             "Universal Default activation key: %s")
 
 # Error Messages.
@@ -284,7 +255,7 @@ SSL_CERT_ERROR_MSG         = _("<b><span size=\"16000\">Incompatible Certificate
                                "The certificate you provided, <b>%s</b>, is not compatible with "
                                " the Red Hat Network server at <b>%s</b>. You may want to double-check"
                                " that you have provided a valid certificate file."
-                               " Are you sure you have provided the correct certificate, and that" 
+                               " Are you sure you have provided the correct certificate, and that"
                                " the certificate file has not been corrupted?\n\n"
                                "Please try again with a different certificate file.")
 
@@ -315,7 +286,7 @@ CHANNEL_PAGE_WARNING = _("Warning:You will not be able to limit this"
                           " system to minor release that is older than"
                           " the recent minor release if you select this"
                           " option.\n")
- 
+
 CONFIRM_OS_WARNING      = _("Your system will be subscribed to %s \n"
                             "base software channel. You will not be\n"
                             "able to move this system to an earlier release\n"
